/* Eclipse Projekt for Yagarto
 * Prozessor: Kinetics MK60N512VMD100
 * Tested on: Freescale Tower System
 *
 * Author: David Thiesbrummel (www.david-th.de)
 * Student at Georg-Simon-Ohm Hochschule, Germany (www.ohm-hochschule.de)
 * Date: 27.04.2012
 * Status: running
 * 
 * SW2 create pseudo random number
 * 4 LEDs show 4Bit number
 */

#include <stdio.h>
#include "MK60N512VMD100.h"  /* include peripheral declarations */

//Function declarations
void port_init_K60(void);
void delay(void);
void __init_hardware(void);

int main(void)
{
	__init_hardware();
	/* Initialize GPIO on TWR-K60N512 */
	port_init_K60();
	 
	GPIOA_PDOR |= 0x30000C00;// at first all LEDs off

	int hexzahl=0,sw2,led1,led2,led3,led4;

    while(1)
    {
    	sw2=GPIOE_PDIR;	//read SW2, low active
    	if(sw2==0) {	//SW2=0 -> SW2 is pushed
    		//while SW2 is pushed, count up for pseudo random number
    		while(sw2==0) {
    	    	sw2=GPIOE_PDIR;	// read SW2 for change
    			hexzahl++;		// increment for pseudo random number
    		}
    		// only 4 LEDs! cutoff not necessary bits and
    		// read out single LEDs to shift for portA
    		led1=hexzahl & 0x00000001;
    		led2=hexzahl & 0x00000002;
    		led3=hexzahl & 0x00000004;
    		led4=hexzahl & 0x00000008;
    		// shift LEDs on portA (PTA11,PTA28...)
    		led1= led1<<11;
    		led2= led2<<27;
    		led3= led3<<27;
    		led4= led4<<7;
    		// write led status out on portA
            GPIOA_PDOR &= ~led1;   // orange LED on (right)(PTA11)
            GPIOA_PDOR &= ~led2;   // yellow LED (middle right)on (PTA28)
            GPIOA_PDOR &= ~led3;   // green LED (middle left) on (PTA29)
            GPIOA_PDOR &= ~led4;   // blue LED (left) on (PTA10)
            // show pseudo random number for three seconds
        	delay();
        	delay();
        	delay();
    		GPIOA_PDOR |= 0x30000C00;       // all LEDs off
    		delay();
    	}
    	// show that program is running and wait for input loop
    	GPIOA_PDOR &= 0xCFFFF3FF;	// all LEDs on
    	delay();
    	GPIOA_PDOR |= 0x30000C00;	// all LEDs off
    	delay();
    }
	return 0;
}


/*
** ===================================================================
 * Method      :  port_init_K60 (component MK60N512MD100)
 * Initialize GPIO for Tower switches and LED's
 *
 *   PTA19 - SW1
 *   PTE26 - SW2
 *
 *   PTA10 - Blue (E4)
 *   PTA29 - Green (E3)
 *   PTA28 - Yellow (E2)
 *   PTA11 - Orange (E1)
** ===================================================================
 */
void port_init_K60()
{
  /* SIM_SCGC5: PORTA=1 */
//  SIM_SCGC5 |= (uint32_t)0x0200UL;     /* Enable clock gate for portA to enable pin routing */
  /* Enable clock gate for PortA and PortE to enable pin routing */
  SIM_SCGC5 = SIM_SCGC5_PORTA_MASK | SIM_SCGC5_PORTE_MASK;

  //PORTA_PAR: Set PTA10, PTA11, PTA28, and PTA29 (connected to LEDs) for GPIO functionality
  //           Set PTA19 (connected to SW1) and PTE26 (connected to SW2) for GPIO functionality
  PORTA_PCR10 = (0|PORT_PCR_MUX(1));
  PORTA_PCR11 = (0|PORT_PCR_MUX(1));
  PORTA_PCR28 = (0|PORT_PCR_MUX(1));
  PORTA_PCR29 = (0|PORT_PCR_MUX(1));
  PORTA_PCR19 = (0|PORT_PCR_MUX(1));
  PORTA_PCR19 |= 0x00000003;	// enable pullup for SW1
  PORTE_PCR26 = (0|PORT_PCR_MUX(1));
  PORTE_PCR26 |= 0x00000003;	// enable pullup for SW2


  //Change PTA10, PTA11, PTA28, PTA29 to outputs, PTA19 to input
//  GPIOA_PDDR=GPIO_PDDR_PDD(GPIO_PIN(10) | GPIO_PIN(11) | GPIO_PIN(28) | GPIO_PIN(29) );	
  GPIOA_PDDR=0x30000C00;			// logic 1 means output
}



/*=========================
** simple wait loop
** waiting about 1s
**=========================
*/
void delay()
{
  unsigned int i, n;
  for(i=0;i<50;i++)					// 50 is about 1 s at 20 - 25 Mhz
  {
    for(n=0;n<30000;n++)
    {
      asm("nop");
    }
  }
}

/*
** ===================================================================
**     Method      :  __init_hardware (component MK60N512MD100)
**
**     Description :
**         Initialization code for CPU core and a clock source.
** ===================================================================
*/
void __init_hardware(void)
{
  /* Disable the WDOG module */
  /* WDOG_UNLOCK: WDOGUNLOCK=0xC520 */
  WDOG_UNLOCK = (uint16_t)0xC520U;     /* Key 1 */
  /* WDOG_UNLOCK : WDOGUNLOCK=0xD928 */
  WDOG_UNLOCK  = (uint16_t)0xD928U;    /* Key 2 */
  /* WDOG_STCTRLH: DISTESTWDOG=0,BYTESEL=0,TESTSEL=0,TESTWDOG=0,STNDBYEN=1,WAITEN=1,STOPEN=1,DBGEN=0,ALLOWUPDATE=1,WINEN=0,IRQRSTEN=0,CLKSRC=1,WDOGEN=0 */
  WDOG_STCTRLH = (uint16_t)0x01D2U;

  // Without further clock initialization the CPU runs at 20 to 25 MHz.
}
